@@ -9,7 +9,7 @@ describe('boolean flag on program', () => {
     program
       .option('--pepper', 'add pepper');
     program.parse(['node', 'test']);
-    expect(program.pepper).toBeUndefined();
+    expect(program.opts().pepper).toBeUndefined();
   });
 
   test('when boolean flag specified then value is true', () => {
@@ -17,7 +17,7 @@ describe('boolean flag on program', () => {
     program
       .option('--pepper', 'add pepper');
     program.parse(['node', 'test', '--pepper']);
-    expect(program.pepper).toBe(true);
+    expect(program.opts().pepper).toBe(true);
   });
 
   test('when negatable boolean flag not specified then value is true', () => {
@@ -25,7 +25,7 @@ describe('boolean flag on program', () => {
     program
       .option('--no-cheese', 'remove cheese');
     program.parse(['node', 'test']);
-    expect(program.cheese).toBe(true);
+    expect(program.opts().cheese).toBe(true);
   });
 
   test('when negatable boolean flag specified then value is false', () => {
@@ -33,78 +33,87 @@ describe('boolean flag on program', () => {
     program
       .option('--no-cheese', 'remove cheese');
     program.parse(['node', 'test', '--no-cheese']);
-    expect(program.cheese).toBe(false);
+    expect(program.opts().cheese).toBe(false);
   });
 });
 
 // boolean flag on command
 describe('boolean flag on command', () => {
   test('when boolean flag not specified then value is undefined', () => {
-    let subCommand;
+    let subCommandOptions;
     const program = new commander.Command();
     program
       .command('sub')
       .option('--pepper', 'add pepper')
-      .action((cmd) => { subCommand = cmd; });
+      .action((options) => { subCommandOptions = options; });
     program.parse(['node', 'test', 'sub']);
-    expect(subCommand.pepper).toBeUndefined();
+    expect(subCommandOptions.pepper).toBeUndefined();
   });
 
   test('when boolean flag specified then value is true', () => {
-    let subCommand;
+    let subCommandOptions;
     const program = new commander.Command();
     program
       .command('sub')
       .option('--pepper', 'add pepper')
-      .action((cmd) => { subCommand = cmd; });
+      .action((options) => { subCommandOptions = options; });
     program.parse(['node', 'test', 'sub', '--pepper']);
-    expect(subCommand.pepper).toBe(true);
+    expect(subCommandOptions.pepper).toBe(true);
   });
 
   test('when negatable boolean flag not specified then value is true', () => {
-    let subCommand;
+    let subCommandOptions;
     const program = new commander.Command();
     program
       .command('sub')
       .option('--no-cheese', 'remove cheese')
-      .action((cmd) => { subCommand = cmd; });
+      .action((options) => { subCommandOptions = options; });
     program.parse(['node', 'test', 'sub']);
-    expect(subCommand.cheese).toBe(true);
+    expect(subCommandOptions.cheese).toBe(true);
   });
 
   test('when negatable boolean flag specified then value is false', () => {
-    let subCommand;
+    let subCommandOptions;
     const program = new commander.Command();
     program
       .command('sub')
       .option('--no-cheese', 'remove cheese')
-      .action((cmd) => { subCommand = cmd; });
+      .action((options) => { subCommandOptions = options; });
     program.parse(['node', 'test', 'sub', '--no-cheese']);
-    expect(subCommand.cheese).toBe(false);
+    expect(subCommandOptions.cheese).toBe(false);
   });
 });
 
-// This is a somewhat undocumented special behaviour which appears in some examples.
-// When a flag has a non-boolean default, it is used as the value (only) when the flag is specified.
-//
 // boolean flag with non-boolean default
+// NB: behaviour changed in Commander v9 to have default be default.
+// These tests no longer match likely uses, but retained and updated to match current behaviour.
 describe('boolean flag with non-boolean default', () => {
-  test('when flag not specified then value is undefined', () => {
+  test('when flag not specified then value is "default"', () => {
     const flagValue = 'black';
     const program = new commander.Command();
     program
-      .option('--olives', 'Add olives? Sorry we only have black.', flagValue);
+      .option('--olives', 'Add green olives?', flagValue);
     program.parse(['node', 'test']);
-    expect(program.olives).toBeUndefined();
+    expect(program.opts().olives).toBe(flagValue);
   });
 
-  test('when flag specified then value is "default" value', () => {
+  test('when flag specified then value is true', () => {
     const flagValue = 'black';
     const program = new commander.Command();
     program
-      .option('-v, --olives', 'Add olives? Sorry we only have black.', flagValue);
+      .option('-v, --olives', 'Add green olives?', flagValue);
     program.parse(['node', 'test', '--olives']);
-    expect(program.olives).toBe(flagValue);
+    expect(program.opts().olives).toBe(true);
+  });
+
+  test('when combo flag and negated then value is false', () => {
+    const flagValue = 'black';
+    const program = new commander.Command();
+    program
+      .option('-v, --olives', 'Add green olives?', flagValue)
+      .option('--no-olives');
+    program.parse(['node', 'test', '--olives', '--no-olives']);
+    expect(program.opts().olives).toBe(false);
   });
 });
 
@@ -115,7 +124,7 @@ describe('regression test for -no- in middle of option flag', () => {
     program
       .option('--module-no-parse');
     program.parse(['node', 'test']);
-    expect(program.moduleNoParse).toBeUndefined();
+    expect(program.opts().moduleNoParse).toBeUndefined();
   });
 
   test('when flag specified then value is true', () => {
@@ -123,6 +132,6 @@ describe('regression test for -no- in middle of option flag', () => {
     program
       .option('--module-no-parse');
     program.parse(['node', 'test', '--module-no-parse']);
-    expect(program.moduleNoParse).toEqual(true);
+    expect(program.opts().moduleNoParse).toEqual(true);
   });
 });
